@@ -27,6 +27,7 @@ import (
 
 	"github.com/richardlehane/siegfried"
 	"github.com/richardlehane/siegfried/internal/chart"
+	"github.com/richardlehane/siegfried/internal/logformatter"
 	"github.com/richardlehane/siegfried/pkg/config"
 	"github.com/richardlehane/siegfried/pkg/core"
 	"github.com/richardlehane/siegfried/pkg/loc"
@@ -47,6 +48,7 @@ Usage:
    roy inspect -help
    roy sets -help
    roy compare -help
+   roy version
 `
 
 var inspectUsage = `
@@ -163,10 +165,12 @@ var (
 	_, htimeout, _, _          = config.HarvestOptions()
 	timeout                    = harvest.Duration("timeout", htimeout, "set duration before timing-out harvesting requests e.g. 120s")
 	throttlef                  = harvest.Duration("throttle", 0, "set a time to wait HTTP requests e.g. 50ms")
+	harvestWikidataSigLen      = harvest.Int("siglen", config.WikidataSigLen(), "set minimum signature length for Wikidata, e.g. 6 chars == 3 bytes")
 	harvestWikidataSig         = harvest.Bool("wikidata", false, "harvest a static Wikidata report")
 	harvestWikidataLang        = harvest.String("lang", config.WikidataLang(), "two-letter language-code to download Wikidata strings, e.g. \"de\"")
 	harvestWikidataEndpoint    = harvest.String("wikidataendpoint", config.WikidataEndpoint(), "the endpoint to use to harvest Wikidata definitions from")
 	harvestWikidataWikibaseURL = harvest.String("wikibaseurl", config.WikidataWikibaseURL(), "the permalink baseURL for the Wikibase server")
+	wikidataRevisionHistory    = harvest.Bool("noprov", false, "turn Wikidata revision history off")
 
 	// INSPECT (roy inspect | roy inspect fmt/121 | roy inspect usr/local/mysig.sig | roy inspect 10)
 	inspect         = flag.NewFlagSet("inspect", flag.ExitOnError)
@@ -200,7 +204,7 @@ var (
 func savereps() error {
 	file, err := os.Open(config.Reports())
 	if err != nil {
-		err = os.Mkdir(config.Reports(), os.ModePerm)
+		err = os.MkdirAll(config.Reports(), os.ModePerm)
 		if err != nil {
 			return fmt.Errorf("roy: error making reports directory %s", err)
 		}
@@ -208,7 +212,7 @@ func savereps() error {
 	file.Close()
 	errs := pronom.Harvest()
 	if len(errs) > 0 {
-		return fmt.Errorf("roy: errors saving reports to disk %s", errs)
+		return fmt.Errorf("roy: error saving reports to disk %s", errs)
 	}
 	return nil
 }
@@ -497,13 +501,16 @@ func setHarvestOptions() {
 	if *throttlef > 0 {
 		config.SetHarvestThrottle(*throttlef)
 	}
+	if *harvestWikidataSigLen != config.WikidataSigLen() {
+		config.SetWikidataSigLen(*harvestWikidataSigLen)
+	}
 	if *harvestWikidataLang != "" {
 		config.SetWikidataLang(*harvestWikidataLang)
 	}
 	if *harvestWikidataEndpoint != config.WikidataEndpoint() {
 		// Configure Siegfried to connect to a custom Wikibase instance.
 		if err := configureCustomWikibase(); err != nil {
-			log.Printf("Roy (Wikibase): %s", err)
+			log.Printf("wikibase: %s", err)
 			os.Exit(1)
 		}
 	}
@@ -519,12 +526,16 @@ func setSetsOptions() {
 }
 
 func main() {
+	logformatter.Set("roy", true)
 	var err error
 	if len(os.Args) < 2 {
 		log.Fatal(usage)
 	}
-
 	switch os.Args[1] {
+	case "version", "-version", "v", "-v":
+		version := config.Version()
+		fmt.Printf("roy %d.%d.%d\n", version[0], version[1], version[2])
+		return
 	case "build":
 		err = build.Parse(os.Args[2:])
 		if err == nil {
@@ -553,7 +564,9 @@ func main() {
 			if *harvestChanges {
 				err = pronom.GetReleases(config.Local("release-notes.xml"))
 			} else if *harvestWikidataSig {
-				err = harvestWikidata()
+				history := !*wikidataRevisionHistory
+				log.Printf("retrieving history for Wikidata: %t", history)
+				err = harvestWikidata(history)
 			} else {
 				err = savereps()
 			}
