@@ -91,6 +91,9 @@ func characterise(m []string) ([]string, []string, []int, []int, error) {
 	hx, ascii := []string{}, []string{}
 	hxx, asciix := []int{}, []int{}
 	for _, v := range m {
+		if strings.Count(v, "(") > 1 { // special case fdd000648
+			continue
+		}
 		v = strings.Replace(v, " (ASCII: \"1↵00:\")", "", 1)
 		tokens := strings.SplitN(v, ": ", 2)
 		switch len(tokens) {
@@ -133,7 +136,7 @@ func characterise(m []string) ([]string, []string, []int, []int, error) {
 }
 
 func dehex(h string, off int) ([][]byte, []int, []bool, error) { // return bytes, offsets, and masks
-	repl := strings.NewReplacer("0x", "", " ", "", "\n", "", "\t", "", "\r", "", "{3}", "xxxxxx", "{8}", "xxxxxxxxxxxxxxxx", "{20 bytes of Hex 20}", "2020202020202020202020202020202020202020") // special case fdd000245 {8}, fdd000342 (nl tab within the hex)
+	repl := strings.NewReplacer("0x", "", " ", "", "\n", "", "\t", "", "\r", "", "{1}", "xx", "{2}", "xxxx", "{3}", "xxxxxx", "{8}", "xxxxxxxxxxxxxxxx", "{20 bytes of Hex 20}", "2020202020202020202020202020202020202020") // special case fdd000245 {8}, fdd000342 (nl tab within the hex)
 	h = repl.Replace(h)
 	if len(h)%2 != 0 {
 		return nil, nil, nil, fmt.Errorf("loc: can't dehex %s", h)
